from setuptools import setup

setup(name='netlenium',
      version='1.0.0.1',
      description='Automate Web Browsers such as Chrome, Opera and Firefox  using Netlenium',
      url='https://github.com/intellivoid/Netlenium-Python-Wrapper',
      author='Intellivoid',
      author_email='narrakas@intellivoid.info',
      packages=['netlenium'],
      zip_safe=False
      )
